@@ -12,7 +12,8 @@ def postgres_template():
 
 @extend_init_signature(CacheBackend, postgres_template)
 class PostgresCacheBackend(CacheBackend):
-    """Wrapper for higher-level cache operations. In most cases, the only thing you need to specify here is which storage class(es) to use"""
+    """Wrapper for higher-level cache operations.
+    In most cases, the only thing you need to specify here is which storage class(es) to use"""
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
@@ -28,16 +29,19 @@ class PostgresStorage(BaseCache):
 
     async def contains(self, key: str) -> bool:
         """Check if a key is stored in the cache"""
-        response = await tables.AioHttpCacheRow.select().where(tables.AioHttpCacheRow.key == key).limit(1)
-        return bool(response)
+        await tables.AioHttpCacheRow.raw()
+        response = await tables.AioHttpCacheRow.raw(
+            "SELECT EXISTS(SELECT 1 FROM aiohttp_client_cache WHERE key ={} LIMIT 1) AS exists", key
+        )
+        return response[0]["exists"] if response else False
 
     async def clear(self) -> None:
         """Delete all items from the cache"""
-        await tables.AioHttpCacheRow.delete(force=True)
+        await tables.AioHttpCacheRow.raw("TRUNCATE TABLE aiohttp_client_cache")
 
     async def delete(self, key: str) -> None:
         """Delete an item from the cache"""
-        await tables.AioHttpCacheRow.delete().where(tables.AioHttpCacheRow.key == key)
+        await tables.AioHttpCacheRow.raw("DELETE FROM aiohttp_client_cache WHERE key = {}", key)
 
     async def keys(self) -> AsyncIterable[str]:
         """Get all keys stored in the cache"""
@@ -47,16 +51,15 @@ class PostgresStorage(BaseCache):
 
     async def read(self, key: str) -> ResponseOrKey:
         """Read an item from the cache"""
-        response = (
-            await tables.AioHttpCacheRow.select(tables.AioHttpCacheRow.value)
-            .where(tables.AioHttpCacheRow.key == key)
-            .limit(1)
+        response = await tables.AioHttpCacheRow.raw(
+            "SELECT value FROM aiohttp_client_cache WHERE key = {} LIMIT 1", key
         )
         return self.deserialize(response["value"]) if response else None
 
     async def size(self) -> int:
         """Get the number of items in the cache"""
-        return await tables.AioHttpCacheRow.count()
+        response = await tables.AioHttpCacheRow.raw("SELECT COUNT(*) FROM aiohttp_client_cache")
+        return response[0]["count"] if response else 0
 
     def values(self) -> AsyncIterable[ResponseOrKey]:
         """Get all values stored in the cache"""
@@ -74,7 +77,7 @@ class PostgresStorage(BaseCache):
             """
             INSERT INTO aiohttp_client_cache (key, value)
             VALUES ({}, {})
-            ON CONFLICT (key) DO UPDATE SET value = excluded.value
+            ON CONFLICT (key) DO NOTHING
             """,
             key,
             self.serialize(item),
@@ -82,4 +85,9 @@ class PostgresStorage(BaseCache):
 
     async def bulk_delete(self, keys: set[str]) -> None:
         """Delete multiple items from the cache"""
-        await tables.AioHttpCacheRow.delete().where(tables.AioHttpCacheRow.key.is_in(list(keys)))
+        await tables.AioHttpCacheRow.raw(
+            f"""
+            DELETE FROM aiohttp_client_cache
+            WHERE {tables.AioHttpCacheRow.key.is_in(list(keys)).querystring}
+            """,
+        )
